@@ -1,6 +1,6 @@
 /*
 
-  $Id: gnokii-logo.c,v 1.7 2006/11/01 17:18:01 pkot Exp $
+  $Id$
 
   G N O K I I
 
@@ -63,7 +63,7 @@ void logo_usage(FILE *f)
 		     "          --getlogo op [logofile [network_code]]\n"
 		     "          --getlogo startup [logofile [network_code]]\n"
 		     "          --getlogo caller [caller_group_number [logofile\n"
-		     "                 [network code]]]\n"
+		     "                 [network_code]]]\n"
 		     "          --getlogo {dealer|text}\n"
 		     "          --viewlogo logofile\n"
 		     ));
@@ -84,7 +84,7 @@ static gn_bmp_types set_bitmap_type(char *s)
 
 /* FIXME: Integrate with sendsms */
 /* The following function allows to send logos using SMS */
-int sendlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error sendlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_sms sms;
 	gn_error error;
@@ -106,15 +106,17 @@ int sendlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *stat
 
 	/* The second argument is the destination, ie the phone number of recipient. */
 	memset(&sms.remote.number, 0, sizeof(sms.remote.number));
-	strncpy(sms.remote.number, argv[optind], sizeof(sms.remote.number) - 1);
-	if (sms.remote.number[0] == '+') sms.remote.type = GN_GSM_NUMBER_International;
-	else sms.remote.type = GN_GSM_NUMBER_Unknown;
+	snprintf(sms.remote.number, sizeof(sms.remote.number), "%s", argv[optind]);
+	if (sms.remote.number[0] == '+')
+		sms.remote.type = GN_GSM_NUMBER_International;
+	else
+		sms.remote.type = GN_GSM_NUMBER_Unknown;
 
 	if (loadbitmap(&sms.user_data[0].u.bitmap, argv[optind+1], type, state) != GN_ERR_NONE)
-		return -1;
+		return GN_ERR_FAILED;
 	if (type != sms.user_data[0].u.bitmap.type) {
 		fprintf(stderr, _("Cannot send logo: specified and loaded bitmap type differ!\n"));
-		return -1;
+		return GN_ERR_FAILED;
 	}
 
 	/* If we are sending op logo we can rewrite network code. */
@@ -123,22 +125,21 @@ int sendlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *stat
 		 * The fourth argument, if present, is the Network code of the operator.
 		 * Network code is in this format: "xxx yy".
 		 */
-		memset(sms.user_data[0].u.bitmap.netcode, 0, sizeof(sms.user_data[0].u.bitmap.netcode));
-		strncpy(sms.user_data[0].u.bitmap.netcode, argv[optind+2], sizeof(sms.user_data[0].u.bitmap.netcode) - 1);
+		snprintf(sms.user_data[0].u.bitmap.netcode, sizeof(sms.user_data[0].u.bitmap.netcode), "%s", argv[optind+2]);
 		dprintf("Operator code: %s\n", argv[optind+2]);
 	}
 
 	sms.user_data[1].type = GN_SMS_DATA_None;
 	if (sms.user_data[0].u.bitmap.type == GN_BMP_PictureMessage) {
 		sms.user_data[1].type = GN_SMS_DATA_NokiaText;
-		readtext(&sms.user_data[1], 120);
+		readtext(&sms.user_data[1]);
 		sms.user_data[2].type = GN_SMS_DATA_None;
 	}
 
 	data->message_center = calloc(1, sizeof(gn_sms_message_center));
 	data->message_center->id = 1;
 	if (gn_sm_functions(GN_OP_GetSMSCenter, data, state) == GN_ERR_NONE) {
-		strcpy(sms.smsc.number, data->message_center->smsc.number);
+		snprintf(sms.smsc.number, sizeof(sms.smsc.number), "%s", data->message_center->smsc.number);
 		sms.smsc.type = data->message_center->smsc.type;
 	}
 	free(data->message_center);
@@ -149,8 +150,17 @@ int sendlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *stat
 	data->sms = &sms;
 	error = gn_sms_send(data, state);
 
-	if (error == GN_ERR_NONE) fprintf(stderr, _("Send succeeded!\n"));
-	else fprintf(stderr, _("SMS Send failed (%s)\n"), gn_error_print(error));
+	if (error == GN_ERR_NONE) {
+		if (sms.parts > 1) {
+			int j;
+			fprintf(stderr, _("Message sent in %d parts with reference numbers:"), sms.parts);
+			for (j = 0; j < sms.parts; j++)
+				fprintf(stderr, " %d", sms.reference[j]);
+			fprintf(stderr, "\n");
+		} else
+			fprintf(stderr, _("Send succeeded with reference %d!\n"), sms.reference[0]);
+	} else
+		fprintf(stderr, _("SMS Send failed (%s)\n"), gn_error_print(error));
 
 	return error;
 }
@@ -194,7 +204,7 @@ static gn_error SaveBitmapFileDialog(char *FileName, gn_bmp *bitmap, gn_phone *i
 	return error;
 }
 
-int getlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error getlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_bmp bitmap;
 	gn_error error;
@@ -237,25 +247,25 @@ int getlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 			case GN_BMP_NewOperatorLogo:
 				if (!bitmap.width)
 					goto empty_bitmap;
-				fprintf(stdout, _("Operator logo for %s (%s) network got successfully\n"),
+				fprintf(stderr, _("Operator logo for %s (%s) network got successfully\n"),
 						bitmap.netcode, gn_network_name_get(bitmap.netcode));
 				if (argc == optind + 2) {
-					strncpy(bitmap.netcode, argv[optind + 1], sizeof(bitmap.netcode) - 1);
+					snprintf(bitmap.netcode, sizeof(bitmap.netcode), "%s", argv[optind + 1]);
 					if (!strcmp(gn_network_name_get(bitmap.netcode), _("unknown"))) {
 						fprintf(stderr, _("Sorry, gnokii doesn't know %s network !\n"), bitmap.netcode);
-						return -1;
+						return GN_ERR_FAILED;
 					}
 				}
 				break;
 			case GN_BMP_StartupLogo:
 				if (!bitmap.width)
 					goto empty_bitmap;
-				fprintf(stdout, _("Startup logo got successfully\n"));
+				fprintf(stderr, _("Startup logo got successfully\n"));
 				if (argc == optind + 2) {
-					strncpy(bitmap.netcode, argv[optind + 1], sizeof(bitmap.netcode) - 1);
+					snprintf(bitmap.netcode, sizeof(bitmap.netcode), "%s", argv[optind + 1]);
 					if (!strcmp(gn_network_name_get(bitmap.netcode), _("unknown"))) {
 						fprintf(stderr, _("Sorry, gnokii doesn't know %s network !\n"), bitmap.netcode);
-						return -1;
+						return GN_ERR_FAILED;
 					}
 				}
 				break;
@@ -263,14 +273,14 @@ int getlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 				if (!bitmap.width)
 					fprintf(stderr, _("Your phone doesn't have logo uploaded !\n"));
 				else
-					fprintf(stdout, _("Caller logo got successfully\n"));
+					fprintf(stderr, _("Caller logo got successfully\n"));
 				fprintf(stdout, _("Caller group name: %s, ringing tone: %s (%d)\n"),
 					bitmap.text, get_ringtone_name(bitmap.ringtone, data, state), bitmap.ringtone);
 				if (argc == optind + 3) {
-					strncpy(bitmap.netcode, argv[optind + 2], sizeof(bitmap.netcode) - 1);
+					snprintf(bitmap.netcode, sizeof(bitmap.netcode), "%s", argv[optind + 2]);
 					if (!strcmp(gn_network_name_get(bitmap.netcode), _("unknown"))) {
 						fprintf(stderr, _("Sorry, gnokii doesn't know %s network !\n"), bitmap.netcode);
-						return -1;
+						return GN_ERR_FAILED;
 					}
 				}
 				break;
@@ -279,10 +289,10 @@ int getlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 				break;
 			empty_bitmap:
 				fprintf(stderr, _("Your phone doesn't have logo uploaded !\n"));
-				return -1;
+				return GN_ERR_FAILED;
 			}
 			if ((argc > optind) && (SaveBitmapFileDialog(argv[optind], &bitmap, info) != GN_ERR_NONE))
-				return -1;
+				return GN_ERR_FAILED;
 			break;
 		default:
 			fprintf(stderr, _("Error: %s\n"), gn_error_print(error));
@@ -290,7 +300,7 @@ int getlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 		}
 	} else {
 		fprintf(stderr, _("What kind of logo do you want to get ?\n"));
-		return -1;
+		return GN_ERR_FAILED;
 	}
 
 	return error;
@@ -314,7 +324,7 @@ static gn_error ReadBitmapFileDialog(char *FileName, gn_bmp *bitmap, gn_phone *i
 }
 
 
-int setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
+gn_error setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state)
 {
 	gn_bmp bitmap, oldbit;
 	gn_network_info networkinfo;
@@ -332,7 +342,8 @@ int setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 	switch (bitmap.type) {
 	case GN_BMP_WelcomeNoteText:
 	case GN_BMP_DealerNoteText:
-		if (argc > optind) strncpy(bitmap.text, argv[optind], sizeof(bitmap.text) - 1);
+		if (argc > optind)
+			snprintf(bitmap.text, sizeof(bitmap.text), "%s", argv[optind]);
 		break;
 	case GN_BMP_OperatorLogo:
 		error = (argc > optind) ? ReadBitmapFileDialog(argv[optind], &bitmap, phone) : gn_bmp_null(&bitmap, phone);
@@ -347,14 +358,14 @@ int setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 			gn_bmp_resize(&bitmap, GN_BMP_OperatorLogo, phone);
 
 		if (argc > optind + 1) {
-			strncpy(bitmap.netcode, argv[optind + 1], sizeof(bitmap.netcode) - 1);
+			snprintf(bitmap.netcode, sizeof(bitmap.netcode), "%s", argv[optind + 1]);
 			if (!strcmp(gn_network_name_get(bitmap.netcode), _("unknown"))) {
 				fprintf(stderr, _("Sorry, gnokii doesn't know %s network !\n"), bitmap.netcode);
 				return GN_ERR_UNKNOWN;
 			}
 		} else {
 			if (gn_sm_functions(GN_OP_GetNetworkInfo, data, state) == GN_ERR_NONE)
-				strncpy(bitmap.netcode, networkinfo.network_code, sizeof(bitmap.netcode) - 1);
+				snprintf(bitmap.netcode, sizeof(bitmap.netcode), "%s", networkinfo.network_code);
 		}
 		break;
 	case GN_BMP_StartupLogo:
@@ -377,10 +388,10 @@ int setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 			if (gn_sm_functions(GN_OP_GetBitmap, data, state) == GN_ERR_NONE) {
 				/* We have to get the old name and ringtone!! */
 				bitmap.ringtone = oldbit.ringtone;
-				strncpy(bitmap.text, oldbit.text, sizeof(bitmap.text) - 1);
+				snprintf(bitmap.text, sizeof(bitmap.text), "%s", oldbit.text);
 			}
 			if (argc > optind + 2)
-				strncpy(bitmap.text, argv[optind + 2], sizeof(bitmap.text) - 1);
+				snprintf(bitmap.text, sizeof(bitmap.text), "%s", argv[optind + 2]);
 		}
 		break;
 	default:
@@ -433,7 +444,7 @@ int setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 						gn_sm_functions(GN_OP_SetBitmap, data, state);
 						data->bitmap = &oldbit;
 						gn_sm_functions(GN_OP_GetBitmap, data, state);
-						fprintf(stderr, _("too long, truncated to \"%s\" (length %i)\n"),oldbit.text,strlen(oldbit.text));
+						fprintf(stderr, _("too long, truncated to \"%s\" (length %zi)\n"), oldbit.text, strlen(oldbit.text));
 						return GN_ERR_ENTRYTOOLONG;
 					}
 				}
@@ -462,7 +473,7 @@ int setlogo(int argc, char *argv[], gn_data *data, struct gn_statemachine *state
 	return error;
 }
 
-int viewlogo(char *filename)
+gn_error viewlogo(char *filename)
 {
 	gn_error error;
 	error = gn_file_bitmap_show(filename);
