@@ -1,6 +1,6 @@
 /*
 
-  $Id: xgnokii_xring.c,v 1.12 2007/05/30 21:49:40 dforsi Exp $
+  $Id$
 
   X G N O K I I
 
@@ -52,6 +52,8 @@
  * HISTORY 
  */
 
+#include "config.h"
+
 #ifndef WIN32
 #  include <unistd.h>
 #endif
@@ -108,7 +110,8 @@ static char *whiteend[] = {
 
 
 static void writecolors(char *buf0, char *col0,
-			char *buf1, char *col1, char *buf2, char *col2)
+			char *buf1, char *col1,
+			char *buf2, char *col2)
 {
 	sprintf(buf0, ".	c #%s", col0);
 	sprintf(buf1, "+	c #%s", col1);
@@ -203,7 +206,7 @@ enum {
 	KIE_COUNT
 };
 
-#define WHITE_COUNT 28		/* mit on pianonkosketin englanniksi */
+#define WHITE_COUNT 28		/* mit? on pianonkosketin englanniksi */
 
 struct GUI {
 	GtkWidget *w;
